Class: Google::Apis::PubsubV1::AnalyticsHubSubscriptionInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/pubsub_v1/classes.rb,
lib/google/apis/pubsub_v1/representations.rb,
lib/google/apis/pubsub_v1/representations.rb

Overview

Information about an associated Analytics Hub subscription.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AnalyticsHubSubscriptionInfo

Returns a new instance of AnalyticsHubSubscriptionInfo.



102
103
104
# File 'lib/google/apis/pubsub_v1/classes.rb', line 102

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#listingString

Optional. The name of the associated Analytics Hub listing resource. Pattern: " projects/project/locations/location/dataExchanges/data_exchange/listings/ listing" Corresponds to the JSON property listing

Returns:

  • (String)


94
95
96
# File 'lib/google/apis/pubsub_v1/classes.rb', line 94

def listing
  @listing
end

#subscriptionString

Optional. The name of the associated Analytics Hub subscription resource. Pattern: "projects/project/locations/location/subscriptions/subscription" Corresponds to the JSON property subscription

Returns:

  • (String)


100
101
102
# File 'lib/google/apis/pubsub_v1/classes.rb', line 100

def subscription
  @subscription
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



107
108
109
110
# File 'lib/google/apis/pubsub_v1/classes.rb', line 107

def update!(**args)
  @listing = args[:listing] if args.key?(:listing)
  @subscription = args[:subscription] if args.key?(:subscription)
end