Class: Google::Apis::PubsubV1::AwsMsk

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/pubsub_v1/classes.rb,
lib/google/apis/pubsub_v1/representations.rb,
lib/google/apis/pubsub_v1/representations.rb

Overview

Ingestion settings for Amazon MSK.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AwsMsk

Returns a new instance of AwsMsk.



246
247
248
# File 'lib/google/apis/pubsub_v1/classes.rb', line 246

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aws_role_arnString

Required. AWS role ARN to be used for Federated Identity authentication with Amazon MSK. Check the Pub/Sub docs for how to set up this role and the required permissions that need to be attached to it. Corresponds to the JSON property awsRoleArn

Returns:

  • (String)


219
220
221
# File 'lib/google/apis/pubsub_v1/classes.rb', line 219

def aws_role_arn
  @aws_role_arn
end

#cluster_arnString

Required. The Amazon Resource Name (ARN) that uniquely identifies the cluster. Corresponds to the JSON property clusterArn

Returns:

  • (String)


224
225
226
# File 'lib/google/apis/pubsub_v1/classes.rb', line 224

def cluster_arn
  @cluster_arn
end

#gcp_service_accountString

Required. The GCP service account to be used for Federated Identity authentication with Amazon MSK (via a AssumeRoleWithWebIdentity call for the provided role). The aws_role_arn must be set up with accounts.google.com: sub equals to this service account number. Corresponds to the JSON property gcpServiceAccount

Returns:

  • (String)


232
233
234
# File 'lib/google/apis/pubsub_v1/classes.rb', line 232

def 
  @gcp_service_account
end

#stateString

Output only. An output-only field that indicates the state of the Amazon MSK ingestion source. Corresponds to the JSON property state

Returns:

  • (String)


238
239
240
# File 'lib/google/apis/pubsub_v1/classes.rb', line 238

def state
  @state
end

#topicString

Required. The name of the topic in the Amazon MSK cluster that Pub/Sub will import from. Corresponds to the JSON property topic

Returns:

  • (String)


244
245
246
# File 'lib/google/apis/pubsub_v1/classes.rb', line 244

def topic
  @topic
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



251
252
253
254
255
256
257
# File 'lib/google/apis/pubsub_v1/classes.rb', line 251

def update!(**args)
  @aws_role_arn = args[:aws_role_arn] if args.key?(:aws_role_arn)
  @cluster_arn = args[:cluster_arn] if args.key?(:cluster_arn)
  @gcp_service_account = args[:gcp_service_account] if args.key?(:gcp_service_account)
  @state = args[:state] if args.key?(:state)
  @topic = args[:topic] if args.key?(:topic)
end