Class: Google::Apis::PubsubV1::AzureEventHubs
- Inherits:
-
Object
- Object
- Google::Apis::PubsubV1::AzureEventHubs
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/pubsub_v1/classes.rb,
lib/google/apis/pubsub_v1/representations.rb,
lib/google/apis/pubsub_v1/representations.rb
Overview
Ingestion settings for Azure Event Hubs.
Instance Attribute Summary collapse
-
#client_id ⇒ String
Optional.
-
#event_hub ⇒ String
Optional.
-
#gcp_service_account ⇒ String
Optional.
-
#namespace ⇒ String
Optional.
-
#resource_group ⇒ String
Optional.
-
#state ⇒ String
Output only.
-
#subscription_id ⇒ String
Optional.
-
#tenant_id ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AzureEventHubs
constructor
A new instance of AzureEventHubs.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AzureEventHubs
Returns a new instance of AzureEventHubs.
308 309 310 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 308 def initialize(**args) update!(**args) end |
Instance Attribute Details
#client_id ⇒ String
Optional. The client id of the Azure application that is being used to
authenticate Pub/Sub.
Corresponds to the JSON property clientId
268 269 270 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 268 def client_id @client_id end |
#event_hub ⇒ String
Optional. The name of the Event Hub.
Corresponds to the JSON property eventHub
273 274 275 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 273 def event_hub @event_hub end |
#gcp_service_account ⇒ String
Optional. The GCP service account to be used for Federated Identity
authentication.
Corresponds to the JSON property gcpServiceAccount
279 280 281 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 279 def gcp_service_account @gcp_service_account end |
#namespace ⇒ String
Optional. The name of the Event Hubs namespace.
Corresponds to the JSON property namespace
284 285 286 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 284 def namespace @namespace end |
#resource_group ⇒ String
Optional. Name of the resource group within the azure subscription.
Corresponds to the JSON property resourceGroup
289 290 291 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 289 def resource_group @resource_group end |
#state ⇒ String
Output only. An output-only field that indicates the state of the Event Hubs
ingestion source.
Corresponds to the JSON property state
295 296 297 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 295 def state @state end |
#subscription_id ⇒ String
Optional. The Azure subscription id.
Corresponds to the JSON property subscriptionId
300 301 302 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 300 def subscription_id @subscription_id end |
#tenant_id ⇒ String
Optional. The tenant id of the Azure application that is being used to
authenticate Pub/Sub.
Corresponds to the JSON property tenantId
306 307 308 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 306 def tenant_id @tenant_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
313 314 315 316 317 318 319 320 321 322 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 313 def update!(**args) @client_id = args[:client_id] if args.key?(:client_id) @event_hub = args[:event_hub] if args.key?(:event_hub) @gcp_service_account = args[:gcp_service_account] if args.key?(:gcp_service_account) @namespace = args[:namespace] if args.key?(:namespace) @resource_group = args[:resource_group] if args.key?(:resource_group) @state = args[:state] if args.key?(:state) @subscription_id = args[:subscription_id] if args.key?(:subscription_id) @tenant_id = args[:tenant_id] if args.key?(:tenant_id) end |