Class: Google::Apis::PubsubV1::CloudStorageConfig
- Inherits:
-
Object
- Object
- Google::Apis::PubsubV1::CloudStorageConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/pubsub_v1/classes.rb,
lib/google/apis/pubsub_v1/representations.rb,
lib/google/apis/pubsub_v1/representations.rb
Overview
Configuration for a Cloud Storage subscription.
Instance Attribute Summary collapse
-
#avro_config ⇒ Google::Apis::PubsubV1::AvroConfig
Configuration for writing message data in Avro format.
-
#bucket ⇒ String
Required.
-
#filename_datetime_format ⇒ String
Optional.
-
#filename_prefix ⇒ String
Optional.
-
#filename_suffix ⇒ String
Optional.
-
#max_bytes ⇒ Fixnum
Optional.
-
#max_duration ⇒ String
Optional.
-
#max_messages ⇒ Fixnum
Optional.
-
#service_account_email ⇒ String
Optional.
-
#state ⇒ String
Output only.
-
#text_config ⇒ Google::Apis::PubsubV1::TextConfig
Configuration for writing message data in text format.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CloudStorageConfig
constructor
A new instance of CloudStorageConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CloudStorageConfig
Returns a new instance of CloudStorageConfig.
713 714 715 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 713 def initialize(**args) update!(**args) end |
Instance Attribute Details
#avro_config ⇒ Google::Apis::PubsubV1::AvroConfig
Configuration for writing message data in Avro format. Message payloads and
metadata will be written to files as an Avro binary.
Corresponds to the JSON property avroConfig
642 643 644 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 642 def avro_config @avro_config end |
#bucket ⇒ String
Required. User-provided name for the Cloud Storage bucket. The bucket must be
created by the user. The bucket name must be without any prefix like "gs://".
See the bucket naming requirements.
Corresponds to the JSON property bucket
650 651 652 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 650 def bucket @bucket end |
#filename_datetime_format ⇒ String
Optional. User-provided format string specifying how to represent datetimes in
Cloud Storage filenames. See the datetime format guidance.
Corresponds to the JSON property filenameDatetimeFormat
657 658 659 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 657 def filename_datetime_format @filename_datetime_format end |
#filename_prefix ⇒ String
Optional. User-provided prefix for Cloud Storage filename. See the object
naming requirements.
Corresponds to the JSON property filenamePrefix
663 664 665 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 663 def filename_prefix @filename_prefix end |
#filename_suffix ⇒ String
Optional. User-provided suffix for Cloud Storage filename. See the object
naming requirements.
Must not end in "/".
Corresponds to the JSON property filenameSuffix
670 671 672 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 670 def filename_suffix @filename_suffix end |
#max_bytes ⇒ Fixnum
Optional. The maximum bytes that can be written to a Cloud Storage file before
a new file is created. Min 1 KB, max 10 GiB. The max_bytes limit may be
exceeded in cases where messages are larger than the limit.
Corresponds to the JSON property maxBytes
677 678 679 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 677 def max_bytes @max_bytes end |
#max_duration ⇒ String
Optional. The maximum duration that can elapse before a new Cloud Storage file
is created. Min 1 minute, max 10 minutes, default 5 minutes. May not exceed
the subscription's acknowledgment deadline.
Corresponds to the JSON property maxDuration
684 685 686 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 684 def max_duration @max_duration end |
#max_messages ⇒ Fixnum
Optional. The maximum number of messages that can be written to a Cloud
Storage file before a new file is created. Min 1000 messages.
Corresponds to the JSON property maxMessages
690 691 692 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 690 def @max_messages end |
#service_account_email ⇒ String
Optional. The service account to use to write to Cloud Storage. The
subscription creator or updater that specifies this field must have iam.
serviceAccounts.actAs permission on the service account. If not specified,
the Pub/Sub service agent,
service-project_number@gcp-sa-pubsub.iam.gserviceaccount.com, is used.
Corresponds to the JSON property serviceAccountEmail
699 700 701 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 699 def service_account_email @service_account_email end |
#state ⇒ String
Output only. An output-only field that indicates whether or not the
subscription can receive messages.
Corresponds to the JSON property state
705 706 707 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 705 def state @state end |
#text_config ⇒ Google::Apis::PubsubV1::TextConfig
Configuration for writing message data in text format. Message payloads will
be written to files as raw text, separated by a newline.
Corresponds to the JSON property textConfig
711 712 713 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 711 def text_config @text_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
718 719 720 721 722 723 724 725 726 727 728 729 730 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 718 def update!(**args) @avro_config = args[:avro_config] if args.key?(:avro_config) @bucket = args[:bucket] if args.key?(:bucket) @filename_datetime_format = args[:filename_datetime_format] if args.key?(:filename_datetime_format) @filename_prefix = args[:filename_prefix] if args.key?(:filename_prefix) @filename_suffix = args[:filename_suffix] if args.key?(:filename_suffix) @max_bytes = args[:max_bytes] if args.key?(:max_bytes) @max_duration = args[:max_duration] if args.key?(:max_duration) @max_messages = args[:max_messages] if args.key?(:max_messages) @service_account_email = args[:service_account_email] if args.key?(:service_account_email) @state = args[:state] if args.key?(:state) @text_config = args[:text_config] if args.key?(:text_config) end |