Class: Google::Apis::PubsubV1::ConfluentCloud
- Inherits:
-
Object
- Object
- Google::Apis::PubsubV1::ConfluentCloud
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/pubsub_v1/classes.rb,
lib/google/apis/pubsub_v1/representations.rb,
lib/google/apis/pubsub_v1/representations.rb
Overview
Ingestion settings for Confluent Cloud.
Instance Attribute Summary collapse
-
#bootstrap_server ⇒ String
Required.
-
#cluster_id ⇒ String
Required.
-
#gcp_service_account ⇒ String
Required.
-
#identity_pool_id ⇒ String
Required.
-
#state ⇒ String
Output only.
-
#topic ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConfluentCloud
constructor
A new instance of ConfluentCloud.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConfluentCloud
Returns a new instance of ConfluentCloud.
790 791 792 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 790 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bootstrap_server ⇒ String
Required. The address of the bootstrap server. The format is url:port.
Corresponds to the JSON property bootstrapServer
757 758 759 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 757 def bootstrap_server @bootstrap_server end |
#cluster_id ⇒ String
Required. The id of the cluster.
Corresponds to the JSON property clusterId
762 763 764 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 762 def cluster_id @cluster_id end |
#gcp_service_account ⇒ String
Required. The GCP service account to be used for Federated Identity
authentication with identity_pool_id.
Corresponds to the JSON property gcpServiceAccount
768 769 770 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 768 def gcp_service_account @gcp_service_account end |
#identity_pool_id ⇒ String
Required. The id of the identity pool to be used for Federated Identity
authentication with Confluent Cloud. See https://docs.confluent.io/cloud/
current/security/authenticate/workload-identities/identity-providers/oauth/
identity-pools.html#add-oauth-identity-pools.
Corresponds to the JSON property identityPoolId
776 777 778 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 776 def identity_pool_id @identity_pool_id end |
#state ⇒ String
Output only. An output-only field that indicates the state of the Confluent
Cloud ingestion source.
Corresponds to the JSON property state
782 783 784 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 782 def state @state end |
#topic ⇒ String
Required. The name of the topic in the Confluent Cloud cluster that Pub/Sub
will import from.
Corresponds to the JSON property topic
788 789 790 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 788 def topic @topic end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
795 796 797 798 799 800 801 802 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 795 def update!(**args) @bootstrap_server = args[:bootstrap_server] if args.key?(:bootstrap_server) @cluster_id = args[:cluster_id] if args.key?(:cluster_id) @gcp_service_account = args[:gcp_service_account] if args.key?(:gcp_service_account) @identity_pool_id = args[:identity_pool_id] if args.key?(:identity_pool_id) @state = args[:state] if args.key?(:state) @topic = args[:topic] if args.key?(:topic) end |