Class: Google::Apis::PubsubV1::ListSchemasResponse
- Inherits:
-
Object
- Object
- Google::Apis::PubsubV1::ListSchemasResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/pubsub_v1/classes.rb,
lib/google/apis/pubsub_v1/representations.rb,
lib/google/apis/pubsub_v1/representations.rb
Overview
Response for the ListSchemas method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
If not empty, indicates that there may be more schemas that match the request; this value should be passed in a new
ListSchemasRequest. -
#schemas ⇒ Array<Google::Apis::PubsubV1::Schema>
The resulting schemas.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListSchemasResponse
constructor
A new instance of ListSchemasResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListSchemasResponse
Returns a new instance of ListSchemasResponse.
1019 1020 1021 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 1019 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
If not empty, indicates that there may be more schemas that match the request;
this value should be passed in a new ListSchemasRequest.
Corresponds to the JSON property nextPageToken
1012 1013 1014 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 1012 def next_page_token @next_page_token end |
#schemas ⇒ Array<Google::Apis::PubsubV1::Schema>
The resulting schemas.
Corresponds to the JSON property schemas
1017 1018 1019 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 1017 def schemas @schemas end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1024 1025 1026 1027 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 1024 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @schemas = args[:schemas] if args.key?(:schemas) end |