Class: Google::Apis::PubsubV1::ListTopicSnapshotsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/pubsub_v1/classes.rb,
lib/google/apis/pubsub_v1/representations.rb,
lib/google/apis/pubsub_v1/representations.rb

Overview

Response for the ListTopicSnapshots method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListTopicSnapshotsResponse

Returns a new instance of ListTopicSnapshotsResponse.



1099
1100
1101
# File 'lib/google/apis/pubsub_v1/classes.rb', line 1099

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

Optional. If not empty, indicates that there may be more snapshots that match the request; this value should be passed in a new ListTopicSnapshotsRequest to get more snapshots. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1092
1093
1094
# File 'lib/google/apis/pubsub_v1/classes.rb', line 1092

def next_page_token
  @next_page_token
end

#snapshotsArray<String>

Optional. The names of the snapshots that match the request. Corresponds to the JSON property snapshots

Returns:

  • (Array<String>)


1097
1098
1099
# File 'lib/google/apis/pubsub_v1/classes.rb', line 1097

def snapshots
  @snapshots
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1104
1105
1106
1107
# File 'lib/google/apis/pubsub_v1/classes.rb', line 1104

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @snapshots = args[:snapshots] if args.key?(:snapshots)
end