Class: Google::Apis::PubsubV1::MessageTransform

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/pubsub_v1/classes.rb,
lib/google/apis/pubsub_v1/representations.rb,
lib/google/apis/pubsub_v1/representations.rb

Overview

All supported message transforms types.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MessageTransform

Returns a new instance of MessageTransform.



1362
1363
1364
# File 'lib/google/apis/pubsub_v1/classes.rb', line 1362

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ai_inferenceGoogle::Apis::PubsubV1::AiInference

Configuration for making inference requests against Vertex AI models. Corresponds to the JSON property aiInference



1334
1335
1336
# File 'lib/google/apis/pubsub_v1/classes.rb', line 1334

def ai_inference
  @ai_inference
end

#compressionGoogle::Apis::PubsubV1::Compression

Configuration for compressing/decompressing message data using a user- specified compression algorithm. Corresponds to the JSON property compression



1340
1341
1342
# File 'lib/google/apis/pubsub_v1/classes.rb', line 1340

def compression
  @compression
end

#disabledBoolean Also known as: disabled?

Optional. If true, the transform is disabled and will not be applied to messages. Defaults to false. Corresponds to the JSON property disabled

Returns:

  • (Boolean)


1346
1347
1348
# File 'lib/google/apis/pubsub_v1/classes.rb', line 1346

def disabled
  @disabled
end

#enabledBoolean Also known as: enabled?

Optional. This field is deprecated, use the disabled field to disable transforms. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


1353
1354
1355
# File 'lib/google/apis/pubsub_v1/classes.rb', line 1353

def enabled
  @enabled
end

#javascript_udfGoogle::Apis::PubsubV1::JavaScriptUdf

User-defined JavaScript function that can transform or filter a Pub/Sub message. Corresponds to the JSON property javascriptUdf



1360
1361
1362
# File 'lib/google/apis/pubsub_v1/classes.rb', line 1360

def javascript_udf
  @javascript_udf
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1367
1368
1369
1370
1371
1372
1373
# File 'lib/google/apis/pubsub_v1/classes.rb', line 1367

def update!(**args)
  @ai_inference = args[:ai_inference] if args.key?(:ai_inference)
  @compression = args[:compression] if args.key?(:compression)
  @disabled = args[:disabled] if args.key?(:disabled)
  @enabled = args[:enabled] if args.key?(:enabled)
  @javascript_udf = args[:javascript_udf] if args.key?(:javascript_udf)
end