Class: Google::Apis::PubsubV1::OidcToken

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/pubsub_v1/classes.rb,
lib/google/apis/pubsub_v1/representations.rb,
lib/google/apis/pubsub_v1/representations.rb

Overview

Contains information needed for generating an OpenID Connect token.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OidcToken

Returns a new instance of OidcToken.



1330
1331
1332
# File 'lib/google/apis/pubsub_v1/classes.rb', line 1330

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#audienceString

Optional. Audience to be used when generating OIDC token. The audience claim identifies the recipients that the JWT is intended for. The audience value is a single case-sensitive string. Having multiple values (array) for the audience field is not supported. More info about the OIDC JWT token audience here: https://tools.ietf.org/html/rfc7519#section-4.1.3 Note: if not specified, the Push endpoint URL will be used. Corresponds to the JSON property audience

Returns:

  • (String)


1320
1321
1322
# File 'lib/google/apis/pubsub_v1/classes.rb', line 1320

def audience
  @audience
end

#service_account_emailString

Optional. Service account email used for generating the OIDC token. For more information on setting up authentication, see Push subscriptions. Corresponds to the JSON property serviceAccountEmail

Returns:

  • (String)


1328
1329
1330
# File 'lib/google/apis/pubsub_v1/classes.rb', line 1328

def 
  @service_account_email
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1335
1336
1337
1338
# File 'lib/google/apis/pubsub_v1/classes.rb', line 1335

def update!(**args)
  @audience = args[:audience] if args.key?(:audience)
  @service_account_email = args[:service_account_email] if args.key?(:service_account_email)
end