Class: Google::Apis::PubsubV1::PubSubAvroFormat

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/pubsub_v1/classes.rb,
lib/google/apis/pubsub_v1/representations.rb,
lib/google/apis/pubsub_v1/representations.rb

Overview

Configuration for reading Cloud Storage data written via Cloud Storage subscriptions. The data and attributes fields of the originally exported Pub/Sub message will be restored when publishing.

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PubSubAvroFormat

Returns a new instance of PubSubAvroFormat.



1501
1502
1503
# File 'lib/google/apis/pubsub_v1/classes.rb', line 1501

def initialize(**args)
   update!(**args)
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1506
1507
# File 'lib/google/apis/pubsub_v1/classes.rb', line 1506

def update!(**args)
end