Class: Google::Apis::PubsubV1::PublishResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/pubsub_v1/classes.rb,
lib/google/apis/pubsub_v1/representations.rb,
lib/google/apis/pubsub_v1/representations.rb

Overview

Response for the Publish method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PublishResponse

Returns a new instance of PublishResponse.



1637
1638
1639
# File 'lib/google/apis/pubsub_v1/classes.rb', line 1637

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#message_idsArray<String>

Optional. The server-assigned ID of each published message, in the same order as the messages in the request. IDs are guaranteed to be unique within the topic. Corresponds to the JSON property messageIds

Returns:

  • (Array<String>)


1635
1636
1637
# File 'lib/google/apis/pubsub_v1/classes.rb', line 1635

def message_ids
  @message_ids
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1642
1643
1644
# File 'lib/google/apis/pubsub_v1/classes.rb', line 1642

def update!(**args)
  @message_ids = args[:message_ids] if args.key?(:message_ids)
end