Class: Google::Apis::PubsubV1::PullRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/pubsub_v1/classes.rb,
lib/google/apis/pubsub_v1/representations.rb,
lib/google/apis/pubsub_v1/representations.rb

Overview

Request for the Pull method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PullRequest

Returns a new instance of PullRequest.



1749
1750
1751
# File 'lib/google/apis/pubsub_v1/classes.rb', line 1749

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#max_messagesFixnum

Required. The maximum number of messages to return for this request. Must be a positive integer. The Pub/Sub system may return fewer than the number specified. Corresponds to the JSON property maxMessages

Returns:

  • (Fixnum)


1735
1736
1737
# File 'lib/google/apis/pubsub_v1/classes.rb', line 1735

def max_messages
  @max_messages
end

#return_immediatelyBoolean Also known as: return_immediately?

Optional. If this field set to true, the system will respond immediately even if it there are no messages available to return in the Pull response. Otherwise, the system may wait (for a bounded amount of time) until at least one message is available, rather than returning no messages. Warning: setting this field to true is discouraged because it adversely impacts the performance of Pull operations. We recommend that users do not set this field. Corresponds to the JSON property returnImmediately

Returns:

  • (Boolean)


1746
1747
1748
# File 'lib/google/apis/pubsub_v1/classes.rb', line 1746

def return_immediately
  @return_immediately
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1754
1755
1756
1757
# File 'lib/google/apis/pubsub_v1/classes.rb', line 1754

def update!(**args)
  @max_messages = args[:max_messages] if args.key?(:max_messages)
  @return_immediately = args[:return_immediately] if args.key?(:return_immediately)
end