Class: Google::Apis::PubsubV1::PullResponse
- Inherits:
-
Object
- Object
- Google::Apis::PubsubV1::PullResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/pubsub_v1/classes.rb,
lib/google/apis/pubsub_v1/representations.rb,
lib/google/apis/pubsub_v1/representations.rb
Overview
Response for the Pull method.
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#initialize(**args) ⇒ PullResponse
constructor
A new instance of PullResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PullResponse
Returns a new instance of PullResponse.
1773 1774 1775 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 1773 def initialize(**args) update!(**args) end |
Instance Attribute Details
#received_messages ⇒ Array<Google::Apis::PubsubV1::ReceivedMessage>
Optional. Received Pub/Sub messages. The list will be empty if there are no
more messages available in the backlog, or if no messages could be returned
before the request timeout. For JSON, the response can be entirely empty. The
Pub/Sub system may return fewer than the maxMessages requested even if there
are more messages available in the backlog.
Corresponds to the JSON property receivedMessages
1771 1772 1773 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 1771 def @received_messages end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1778 1779 1780 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 1778 def update!(**args) @received_messages = args[:received_messages] if args.key?(:received_messages) end |