Class: Google::Apis::PubsubV1::Schema

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/pubsub_v1/classes.rb,
lib/google/apis/pubsub_v1/representations.rb,
lib/google/apis/pubsub_v1/representations.rb

Overview

A schema resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Schema

Returns a new instance of Schema.



1970
1971
1972
# File 'lib/google/apis/pubsub_v1/classes.rb', line 1970

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#definitionString

The definition of the schema. This should contain a string representing the full definition of the schema that is a valid schema definition of the type specified in type. Corresponds to the JSON property definition

Returns:

  • (String)


1948
1949
1950
# File 'lib/google/apis/pubsub_v1/classes.rb', line 1948

def definition
  @definition
end

#nameString

Required. Name of the schema. Format is projects/project/schemas/schema`. Corresponds to the JSON propertyname`

Returns:

  • (String)


1953
1954
1955
# File 'lib/google/apis/pubsub_v1/classes.rb', line 1953

def name
  @name
end

#revision_create_timeString

Output only. The timestamp that the revision was created. Corresponds to the JSON property revisionCreateTime

Returns:

  • (String)


1958
1959
1960
# File 'lib/google/apis/pubsub_v1/classes.rb', line 1958

def revision_create_time
  @revision_create_time
end

#revision_idString

Output only. Immutable. The revision ID of the schema. Corresponds to the JSON property revisionId

Returns:

  • (String)


1963
1964
1965
# File 'lib/google/apis/pubsub_v1/classes.rb', line 1963

def revision_id
  @revision_id
end

#typeString

The type of the schema definition. Corresponds to the JSON property type

Returns:

  • (String)


1968
1969
1970
# File 'lib/google/apis/pubsub_v1/classes.rb', line 1968

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1975
1976
1977
1978
1979
1980
1981
# File 'lib/google/apis/pubsub_v1/classes.rb', line 1975

def update!(**args)
  @definition = args[:definition] if args.key?(:definition)
  @name = args[:name] if args.key?(:name)
  @revision_create_time = args[:revision_create_time] if args.key?(:revision_create_time)
  @revision_id = args[:revision_id] if args.key?(:revision_id)
  @type = args[:type] if args.key?(:type)
end