Class: Google::Apis::PubsubV1::SchemaSettings
- Inherits:
-
Object
- Object
- Google::Apis::PubsubV1::SchemaSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/pubsub_v1/classes.rb,
lib/google/apis/pubsub_v1/representations.rb,
lib/google/apis/pubsub_v1/representations.rb
Overview
Settings for validating messages published against a schema.
Instance Attribute Summary collapse
-
#encoding ⇒ String
Optional.
-
#first_revision_id ⇒ String
Optional.
-
#last_revision_id ⇒ String
Optional.
-
#schema ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SchemaSettings
constructor
A new instance of SchemaSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SchemaSettings
Returns a new instance of SchemaSettings.
1874 1875 1876 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 1874 def initialize(**args) update!(**args) end |
Instance Attribute Details
#encoding ⇒ String
Optional. The encoding of messages validated against schema.
Corresponds to the JSON property encoding
1851 1852 1853 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 1851 def encoding @encoding end |
#first_revision_id ⇒ String
Optional. The minimum (inclusive) revision allowed for validating messages. If
empty or not present, allow any revision to be validated against last_revision
or any revision created before.
Corresponds to the JSON property firstRevisionId
1858 1859 1860 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 1858 def first_revision_id @first_revision_id end |
#last_revision_id ⇒ String
Optional. The maximum (inclusive) revision allowed for validating messages. If
empty or not present, allow any revision to be validated against
first_revision or any revision created after.
Corresponds to the JSON property lastRevisionId
1865 1866 1867 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 1865 def last_revision_id @last_revision_id end |
#schema ⇒ String
Required. The name of the schema that messages published should be validated
against. Format is projects/project/schemas/schema`. The value of this
field will bedeleted-schemaif the schema has been deleted.
Corresponds to the JSON propertyschema`
1872 1873 1874 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 1872 def schema @schema end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1879 1880 1881 1882 1883 1884 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 1879 def update!(**args) @encoding = args[:encoding] if args.key?(:encoding) @first_revision_id = args[:first_revision_id] if args.key?(:first_revision_id) @last_revision_id = args[:last_revision_id] if args.key?(:last_revision_id) @schema = args[:schema] if args.key?(:schema) end |