Class: Google::Apis::PubsubV1::TextFormat

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/pubsub_v1/classes.rb,
lib/google/apis/pubsub_v1/representations.rb,
lib/google/apis/pubsub_v1/representations.rb

Overview

Configuration for reading Cloud Storage data in text format. Each line of text as specified by the delimiter will be set to the data field of a Pub/Sub message.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TextFormat

Returns a new instance of TextFormat.



2354
2355
2356
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2354

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#delimiterString

Optional. When unset, '\n' is used. Corresponds to the JSON property delimiter

Returns:

  • (String)


2352
2353
2354
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2352

def delimiter
  @delimiter
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2359
2360
2361
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2359

def update!(**args)
  @delimiter = args[:delimiter] if args.key?(:delimiter)
end