Class: Google::Apis::PubsubV1::UnstructuredInference

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/pubsub_v1/classes.rb,
lib/google/apis/pubsub_v1/representations.rb,
lib/google/apis/pubsub_v1/representations.rb

Overview

Configuration for making inferences using arbitrary JSON payloads.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UnstructuredInference

Returns a new instance of UnstructuredInference.



2582
2583
2584
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2582

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#parametersHash<String,Object>

Optional. A parameters object to be included in each inference request. The parameters object is combined with the data field of the Pub/Sub message to form the inference request. Corresponds to the JSON property parameters

Returns:

  • (Hash<String,Object>)


2580
2581
2582
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2580

def parameters
  @parameters
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2587
2588
2589
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2587

def update!(**args)
  @parameters = args[:parameters] if args.key?(:parameters)
end