Class: Google::Apis::PubsubV1::UpdateSubscriptionRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/pubsub_v1/classes.rb,
lib/google/apis/pubsub_v1/representations.rb,
lib/google/apis/pubsub_v1/representations.rb

Overview

Request for the UpdateSubscription method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpdateSubscriptionRequest

Returns a new instance of UpdateSubscriptionRequest.



2641
2642
2643
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2641

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#subscriptionGoogle::Apis::PubsubV1::Subscription

A subscription resource. If none of push_config, bigquery_config, cloud_storage_config, or bigtable_config is set, then the subscriber will pull and ack messages using API methods. At most one of these fields may be set. Corresponds to the JSON property subscription



2633
2634
2635
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2633

def subscription
  @subscription
end

#update_maskString

Required. Indicates which fields in the provided subscription to update. Must be specified and non-empty. Corresponds to the JSON property updateMask

Returns:

  • (String)


2639
2640
2641
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2639

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2646
2647
2648
2649
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2646

def update!(**args)
  @subscription = args[:subscription] if args.key?(:subscription)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end