Class: Google::Apis::PubsubV1::CloudStorage
- Inherits:
-
Object
- Object
- Google::Apis::PubsubV1::CloudStorage
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/pubsub_v1/classes.rb,
lib/google/apis/pubsub_v1/representations.rb,
lib/google/apis/pubsub_v1/representations.rb
Overview
Ingestion settings for Cloud Storage.
Instance Attribute Summary collapse
-
#avro_format ⇒ Google::Apis::PubsubV1::AvroFormat
Configuration for reading Cloud Storage data in Avro binary format.
-
#bucket ⇒ String
Optional.
-
#match_glob ⇒ String
Optional.
-
#minimum_object_create_time ⇒ String
Optional.
-
#pubsub_avro_format ⇒ Google::Apis::PubsubV1::PubSubAvroFormat
Configuration for reading Cloud Storage data written via Cloud Storage subscriptions.
-
#state ⇒ String
Output only.
-
#text_format ⇒ Google::Apis::PubsubV1::TextFormat
Configuration for reading Cloud Storage data in text format.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CloudStorage
constructor
A new instance of CloudStorage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CloudStorage
Returns a new instance of CloudStorage.
555 556 557 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 555 def initialize(**args) update!(**args) end |
Instance Attribute Details
#avro_format ⇒ Google::Apis::PubsubV1::AvroFormat
Configuration for reading Cloud Storage data in Avro binary format. The bytes
of each object will be set to the data field of a Pub/Sub message.
Corresponds to the JSON property avroFormat
511 512 513 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 511 def avro_format @avro_format end |
#bucket ⇒ String
Optional. Cloud Storage bucket. The bucket name must be without any prefix
like "gs://". See the bucket naming requirements.
Corresponds to the JSON property bucket
518 519 520 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 518 def bucket @bucket end |
#match_glob ⇒ String
Optional. Glob pattern used to match objects that will be ingested. If unset,
all objects will be ingested. See the supported patterns.
Corresponds to the JSON property matchGlob
526 527 528 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 526 def match_glob @match_glob end |
#minimum_object_create_time ⇒ String
Optional. Only objects with a larger or equal creation timestamp will be
ingested.
Corresponds to the JSON property minimumObjectCreateTime
532 533 534 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 532 def minimum_object_create_time @minimum_object_create_time end |
#pubsub_avro_format ⇒ Google::Apis::PubsubV1::PubSubAvroFormat
Configuration for reading Cloud Storage data written via Cloud Storage
subscriptions. The data
and attributes fields of the originally exported Pub/Sub message will be
restored when publishing.
Corresponds to the JSON property pubsubAvroFormat
540 541 542 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 540 def pubsub_avro_format @pubsub_avro_format end |
#state ⇒ String
Output only. An output-only field that indicates the state of the Cloud
Storage ingestion source.
Corresponds to the JSON property state
546 547 548 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 546 def state @state end |
#text_format ⇒ Google::Apis::PubsubV1::TextFormat
Configuration for reading Cloud Storage data in text format. Each line of text
as specified by the delimiter will be set to the data field of a Pub/Sub
message.
Corresponds to the JSON property textFormat
553 554 555 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 553 def text_format @text_format end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
560 561 562 563 564 565 566 567 568 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 560 def update!(**args) @avro_format = args[:avro_format] if args.key?(:avro_format) @bucket = args[:bucket] if args.key?(:bucket) @match_glob = args[:match_glob] if args.key?(:match_glob) @minimum_object_create_time = args[:minimum_object_create_time] if args.key?(:minimum_object_create_time) @pubsub_avro_format = args[:pubsub_avro_format] if args.key?(:pubsub_avro_format) @state = args[:state] if args.key?(:state) @text_format = args[:text_format] if args.key?(:text_format) end |