Class: Google::Apis::PubsubV1::CreateSnapshotRequest
- Inherits:
-
Object
- Object
- Google::Apis::PubsubV1::CreateSnapshotRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/pubsub_v1/classes.rb,
lib/google/apis/pubsub_v1/representations.rb,
lib/google/apis/pubsub_v1/representations.rb
Overview
Request for the CreateSnapshot method.
Instance Attribute Summary collapse
-
#labels ⇒ Hash<String,String>
Optional.
-
#subscription ⇒ String
Required.
-
#tags ⇒ Hash<String,String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CreateSnapshotRequest
constructor
A new instance of CreateSnapshotRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CreateSnapshotRequest
Returns a new instance of CreateSnapshotRequest.
772 773 774 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 772 def initialize(**args) update!(**args) end |
Instance Attribute Details
#labels ⇒ Hash<String,String>
Optional. See Creating and managing labels.
Corresponds to the JSON property labels
752 753 754 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 752 def labels @labels end |
#subscription ⇒ String
Required. The subscription whose backlog the snapshot retains. Specifically,
the created snapshot is guaranteed to retain: (a) The existing backlog on the
subscription. More precisely, this is defined as the messages in the
subscription's backlog that are unacknowledged upon the successful completion
of the CreateSnapshot request; as well as: (b) Any messages published to the
subscription's topic following the successful completion of the CreateSnapshot
request. Format is projects/project/subscriptions/sub`.
Corresponds to the JSON propertysubscription`
763 764 765 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 763 def subscription @subscription end |
#tags ⇒ Hash<String,String>
Optional. Input only. Immutable. Tag keys/values directly bound to this
resource. For example: "123/environment": "production", "123/costCenter": "
marketing"
Corresponds to the JSON property tags
770 771 772 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 770 def @tags end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
777 778 779 780 781 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 777 def update!(**args) @labels = args[:labels] if args.key?(:labels) @subscription = args[:subscription] if args.key?(:subscription) @tags = args[:tags] if args.key?(:tags) end |