Class: Google::Apis::PubsubV1::MessageTransform

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/pubsub_v1/classes.rb,
lib/google/apis/pubsub_v1/representations.rb,
lib/google/apis/pubsub_v1/representations.rb

Overview

All supported message transforms types.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MessageTransform

Returns a new instance of MessageTransform.



1328
1329
1330
# File 'lib/google/apis/pubsub_v1/classes.rb', line 1328

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ai_inferenceGoogle::Apis::PubsubV1::AiInference

Configuration for making inference requests against Vertex AI models. Corresponds to the JSON property aiInference



1306
1307
1308
# File 'lib/google/apis/pubsub_v1/classes.rb', line 1306

def ai_inference
  @ai_inference
end

#disabledBoolean Also known as: disabled?

Optional. If true, the transform is disabled and will not be applied to messages. Defaults to false. Corresponds to the JSON property disabled

Returns:

  • (Boolean)


1312
1313
1314
# File 'lib/google/apis/pubsub_v1/classes.rb', line 1312

def disabled
  @disabled
end

#enabledBoolean Also known as: enabled?

Optional. This field is deprecated, use the disabled field to disable transforms. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


1319
1320
1321
# File 'lib/google/apis/pubsub_v1/classes.rb', line 1319

def enabled
  @enabled
end

#javascript_udfGoogle::Apis::PubsubV1::JavaScriptUdf

User-defined JavaScript function that can transform or filter a Pub/Sub message. Corresponds to the JSON property javascriptUdf



1326
1327
1328
# File 'lib/google/apis/pubsub_v1/classes.rb', line 1326

def javascript_udf
  @javascript_udf
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1333
1334
1335
1336
1337
1338
# File 'lib/google/apis/pubsub_v1/classes.rb', line 1333

def update!(**args)
  @ai_inference = args[:ai_inference] if args.key?(:ai_inference)
  @disabled = args[:disabled] if args.key?(:disabled)
  @enabled = args[:enabled] if args.key?(:enabled)
  @javascript_udf = args[:javascript_udf] if args.key?(:javascript_udf)
end