Class: Google::Apis::PubsubV1::MessageTransform
- Inherits:
-
Object
- Object
- Google::Apis::PubsubV1::MessageTransform
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/pubsub_v1/classes.rb,
lib/google/apis/pubsub_v1/representations.rb,
lib/google/apis/pubsub_v1/representations.rb
Overview
All supported message transforms types.
Instance Attribute Summary collapse
-
#ai_inference ⇒ Google::Apis::PubsubV1::AiInference
Configuration for making inference requests against Vertex AI models.
-
#disabled ⇒ Boolean
(also: #disabled?)
Optional.
-
#enabled ⇒ Boolean
(also: #enabled?)
Optional.
-
#javascript_udf ⇒ Google::Apis::PubsubV1::JavaScriptUdf
User-defined JavaScript function that can transform or filter a Pub/Sub message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MessageTransform
constructor
A new instance of MessageTransform.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MessageTransform
Returns a new instance of MessageTransform.
1266 1267 1268 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 1266 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ai_inference ⇒ Google::Apis::PubsubV1::AiInference
Configuration for making inference requests against Vertex AI models.
Corresponds to the JSON property aiInference
1244 1245 1246 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 1244 def ai_inference @ai_inference end |
#disabled ⇒ Boolean Also known as: disabled?
Optional. If true, the transform is disabled and will not be applied to
messages. Defaults to false.
Corresponds to the JSON property disabled
1250 1251 1252 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 1250 def disabled @disabled end |
#enabled ⇒ Boolean Also known as: enabled?
Optional. This field is deprecated, use the disabled field to disable
transforms.
Corresponds to the JSON property enabled
1257 1258 1259 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 1257 def enabled @enabled end |
#javascript_udf ⇒ Google::Apis::PubsubV1::JavaScriptUdf
User-defined JavaScript function that can transform or filter a Pub/Sub
message.
Corresponds to the JSON property javascriptUdf
1264 1265 1266 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 1264 def javascript_udf @javascript_udf end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1271 1272 1273 1274 1275 1276 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 1271 def update!(**args) @ai_inference = args[:ai_inference] if args.key?(:ai_inference) @disabled = args[:disabled] if args.key?(:disabled) @enabled = args[:enabled] if args.key?(:enabled) @javascript_udf = args[:javascript_udf] if args.key?(:javascript_udf) end |