Class: Google::Apis::PubsubV1::ModifyAckDeadlineRequest
- Inherits:
-
Object
- Object
- Google::Apis::PubsubV1::ModifyAckDeadlineRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/pubsub_v1/classes.rb,
lib/google/apis/pubsub_v1/representations.rb,
lib/google/apis/pubsub_v1/representations.rb
Overview
Request for the ModifyAckDeadline method.
Instance Attribute Summary collapse
-
#ack_deadline_seconds ⇒ Fixnum
Required.
-
#ack_ids ⇒ Array<String>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ModifyAckDeadlineRequest
constructor
A new instance of ModifyAckDeadlineRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ModifyAckDeadlineRequest
Returns a new instance of ModifyAckDeadlineRequest.
1362 1363 1364 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 1362 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ack_deadline_seconds ⇒ Fixnum
Required. The new ack deadline with respect to the time this request was sent
to the Pub/Sub system. For example, if the value is 10, the new ack deadline
will expire 10 seconds after the ModifyAckDeadline call was made. Specifying
zero might immediately make the message available for delivery to another
subscriber client. This typically results in an increase in the rate of
message redeliveries (that is, duplicates). The minimum deadline you can
specify is 0 seconds. The maximum deadline you can specify in a single request
is 600 seconds (10 minutes).
Corresponds to the JSON property ackDeadlineSeconds
1355 1356 1357 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 1355 def ack_deadline_seconds @ack_deadline_seconds end |
#ack_ids ⇒ Array<String>
Required. List of acknowledgment IDs.
Corresponds to the JSON property ackIds
1360 1361 1362 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 1360 def ack_ids @ack_ids end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1367 1368 1369 1370 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 1367 def update!(**args) @ack_deadline_seconds = args[:ack_deadline_seconds] if args.key?(:ack_deadline_seconds) @ack_ids = args[:ack_ids] if args.key?(:ack_ids) end |