Class: Google::Apis::PubsubV1::PushConfig
- Inherits:
-
Object
- Object
- Google::Apis::PubsubV1::PushConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/pubsub_v1/classes.rb,
lib/google/apis/pubsub_v1/representations.rb,
lib/google/apis/pubsub_v1/representations.rb
Overview
Configuration for a push delivery endpoint.
Instance Attribute Summary collapse
-
#attributes ⇒ Hash<String,String>
Optional.
-
#no_wrapper ⇒ Google::Apis::PubsubV1::NoWrapper
Sets the
datafield as the HTTP body for delivery. -
#oidc_token ⇒ Google::Apis::PubsubV1::OidcToken
Contains information needed for generating an OpenID Connect token.
-
#pubsub_wrapper ⇒ Google::Apis::PubsubV1::PubsubWrapper
The payload to the push endpoint is in the form of the JSON representation of a PubsubMessage (https://cloud.google.com/pubsub/docs/reference/rpc/google. pubsub.v1#pubsubmessage).
-
#push_endpoint ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PushConfig
constructor
A new instance of PushConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PushConfig
Returns a new instance of PushConfig.
1793 1794 1795 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 1793 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attributes ⇒ Hash<String,String>
Optional. Endpoint configuration attributes that can be used to control
different aspects of the message delivery. The only currently supported
attribute is x-goog-version, which you can use to change the format of the
pushed message. This attribute indicates the version of the data expected by
the endpoint. This controls the shape of the pushed message (i.e., its fields
and metadata). If not present during the CreateSubscription call, it will
default to the version of the Pub/Sub API used to make such call. If not
present in a ModifyPushConfig call, its value will not be changed.
GetSubscription calls will always return a valid version, even if the
subscription was created without this attribute. The only supported values for
the x-goog-version attribute are: * v1beta1: uses the push format defined
in the v1beta1 Pub/Sub API. * v1 or v1beta2: uses the push format defined
in the v1 Pub/Sub API. For example: attributes "x-goog-version": "v1" `
Corresponds to the JSON propertyattributes`
1767 1768 1769 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 1767 def attributes @attributes end |
#no_wrapper ⇒ Google::Apis::PubsubV1::NoWrapper
Sets the data field as the HTTP body for delivery.
Corresponds to the JSON property noWrapper
1772 1773 1774 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 1772 def no_wrapper @no_wrapper end |
#oidc_token ⇒ Google::Apis::PubsubV1::OidcToken
Contains information needed for generating an OpenID Connect token.
Corresponds to the JSON property oidcToken
1778 1779 1780 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 1778 def oidc_token @oidc_token end |
#pubsub_wrapper ⇒ Google::Apis::PubsubV1::PubsubWrapper
The payload to the push endpoint is in the form of the JSON representation of
a PubsubMessage (https://cloud.google.com/pubsub/docs/reference/rpc/google.
pubsub.v1#pubsubmessage).
Corresponds to the JSON property pubsubWrapper
1785 1786 1787 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 1785 def pubsub_wrapper @pubsub_wrapper end |
#push_endpoint ⇒ String
Optional. A URL locating the endpoint to which messages should be pushed. For
example, a Webhook endpoint might use https://example.com/push.
Corresponds to the JSON property pushEndpoint
1791 1792 1793 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 1791 def push_endpoint @push_endpoint end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1798 1799 1800 1801 1802 1803 1804 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 1798 def update!(**args) @attributes = args[:attributes] if args.key?(:attributes) @no_wrapper = args[:no_wrapper] if args.key?(:no_wrapper) @oidc_token = args[:oidc_token] if args.key?(:oidc_token) @pubsub_wrapper = args[:pubsub_wrapper] if args.key?(:pubsub_wrapper) @push_endpoint = args[:push_endpoint] if args.key?(:push_endpoint) end |