Class: Google::Apis::PubsubV1::SeekRequest
- Inherits:
-
Object
- Object
- Google::Apis::PubsubV1::SeekRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/pubsub_v1/classes.rb,
lib/google/apis/pubsub_v1/representations.rb,
lib/google/apis/pubsub_v1/representations.rb
Overview
Request for the Seek method.
Instance Attribute Summary collapse
-
#snapshot ⇒ String
Optional.
-
#time ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SeekRequest
constructor
A new instance of SeekRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SeekRequest
Returns a new instance of SeekRequest.
2019 2020 2021 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2019 def initialize(**args) update!(**args) end |
Instance Attribute Details
#snapshot ⇒ String
Optional. The snapshot to seek to. The snapshot's topic must be the same as
that of the provided subscription. Format is projects/project/snapshots/
snap`.
Corresponds to the JSON propertysnapshot`
2003 2004 2005 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2003 def snapshot @snapshot end |
#time ⇒ String
Optional. The time to seek to. Messages retained in the subscription that were
published before this time are marked as acknowledged, and messages retained
in the subscription that were published after this time are marked as
unacknowledged. Note that this operation affects only those messages retained
in the subscription (configured by the combination of
message_retention_duration and retain_acked_messages). For example, if
time corresponds to a point before the message retention window (or to a
point before the system's notion of the subscription creation time), only
retained messages will be marked as unacknowledged, and already-expunged
messages will not be restored.
Corresponds to the JSON property time
2017 2018 2019 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2017 def time @time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2024 2025 2026 2027 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2024 def update!(**args) @snapshot = args[:snapshot] if args.key?(:snapshot) @time = args[:time] if args.key?(:time) end |