Class: Google::Apis::PubsubV1::Snapshot

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/pubsub_v1/classes.rb,
lib/google/apis/pubsub_v1/representations.rb,
lib/google/apis/pubsub_v1/representations.rb

Overview

A snapshot resource. Snapshots are used in Seek operations, which allow you to manage message acknowledgments in bulk. That is, you can set the acknowledgment state of messages in an existing subscription to the state captured by a snapshot.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Snapshot

Returns a new instance of Snapshot.



2063
2064
2065
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2063

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#expire_timeString

Optional. The snapshot is guaranteed to exist up until this time. A newly- created snapshot expires no later than 7 days from the time of its creation. Its exact lifetime is determined at creation by the existing backlog in the source subscription. Specifically, the lifetime of the snapshot is 7 days - ( age of oldest unacked message in the subscription). For example, consider a subscription whose oldest unacked message is 3 days old. If a snapshot is created from this subscription, the snapshot -- which will always capture this 3-day-old backlog as long as the snapshot exists -- will expire in 4 days. The service will refuse to create a snapshot that would expire in less than 1 hour after creation. Corresponds to the JSON property expireTime

Returns:

  • (String)


2045
2046
2047
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2045

def expire_time
  @expire_time
end

#labelsHash<String,String>

Optional. See Creating and managing labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


2051
2052
2053
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2051

def labels
  @labels
end

#nameString

Optional. The name of the snapshot. Corresponds to the JSON property name

Returns:

  • (String)


2056
2057
2058
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2056

def name
  @name
end

#topicString

Optional. The name of the topic from which this snapshot is retaining messages. Corresponds to the JSON property topic

Returns:

  • (String)


2061
2062
2063
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2061

def topic
  @topic
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2068
2069
2070
2071
2072
2073
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2068

def update!(**args)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @topic = args[:topic] if args.key?(:topic)
end