Class: Google::Apis::PubsubV1::Snapshot
- Inherits:
-
Object
- Object
- Google::Apis::PubsubV1::Snapshot
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/pubsub_v1/classes.rb,
lib/google/apis/pubsub_v1/representations.rb,
lib/google/apis/pubsub_v1/representations.rb
Overview
A snapshot resource. Snapshots are used in Seek operations, which allow you to manage message acknowledgments in bulk. That is, you can set the acknowledgment state of messages in an existing subscription to the state captured by a snapshot.
Instance Attribute Summary collapse
-
#expire_time ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Optional.
-
#topic ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Snapshot
constructor
A new instance of Snapshot.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Snapshot
Returns a new instance of Snapshot.
2018 2019 2020 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2018 def initialize(**args) update!(**args) end |
Instance Attribute Details
#expire_time ⇒ String
Optional. The snapshot is guaranteed to exist up until this time. A newly-
created snapshot expires no later than 7 days from the time of its creation.
Its exact lifetime is determined at creation by the existing backlog in the
source subscription. Specifically, the lifetime of the snapshot is 7 days - (
age of oldest unacked message in the subscription). For example, consider a
subscription whose oldest unacked message is 3 days old. If a snapshot is
created from this subscription, the snapshot -- which will always capture this
3-day-old backlog as long as the snapshot exists -- will expire in 4 days. The
service will refuse to create a snapshot that would expire in less than 1 hour
after creation.
Corresponds to the JSON property expireTime
2000 2001 2002 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2000 def expire_time @expire_time end |
#labels ⇒ Hash<String,String>
Optional. See Creating and managing labels.
Corresponds to the JSON property labels
2006 2007 2008 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2006 def labels @labels end |
#name ⇒ String
Optional. The name of the snapshot.
Corresponds to the JSON property name
2011 2012 2013 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2011 def name @name end |
#topic ⇒ String
Optional. The name of the topic from which this snapshot is retaining messages.
Corresponds to the JSON property topic
2016 2017 2018 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2016 def topic @topic end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2023 2024 2025 2026 2027 2028 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2023 def update!(**args) @expire_time = args[:expire_time] if args.key?(:expire_time) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @topic = args[:topic] if args.key?(:topic) end |