Class: Google::Apis::PubsubV1::Subscription
- Inherits:
-
Object
- Object
- Google::Apis::PubsubV1::Subscription
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/pubsub_v1/classes.rb,
lib/google/apis/pubsub_v1/representations.rb,
lib/google/apis/pubsub_v1/representations.rb
Overview
A subscription resource. If none of push_config, bigquery_config,
cloud_storage_config, or bigtable_config is set, then the subscriber will
pull and ack messages using API methods. At most one of these fields may be
set.
Instance Attribute Summary collapse
-
#ack_deadline_seconds ⇒ Fixnum
Optional.
-
#analytics_hub_subscription_info ⇒ Google::Apis::PubsubV1::AnalyticsHubSubscriptionInfo
Information about an associated Analytics Hub subscription.
-
#bigquery_config ⇒ Google::Apis::PubsubV1::BigQueryConfig
Configuration for a BigQuery subscription.
-
#bigtable_config ⇒ Google::Apis::PubsubV1::BigtableConfig
Configuration for a Bigtable subscription.
-
#cloud_storage_config ⇒ Google::Apis::PubsubV1::CloudStorageConfig
Configuration for a Cloud Storage subscription.
-
#dead_letter_policy ⇒ Google::Apis::PubsubV1::DeadLetterPolicy
Dead lettering is done on a best effort basis.
-
#detached ⇒ Boolean
(also: #detached?)
Optional.
-
#enable_exactly_once_delivery ⇒ Boolean
(also: #enable_exactly_once_delivery?)
Optional.
-
#enable_message_ordering ⇒ Boolean
(also: #enable_message_ordering?)
Optional.
-
#expiration_policy ⇒ Google::Apis::PubsubV1::ExpirationPolicy
A policy that specifies the conditions for resource expiration (i.e., automatic resource deletion).
-
#filter ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#message_retention_duration ⇒ String
Optional.
-
#message_transforms ⇒ Array<Google::Apis::PubsubV1::MessageTransform>
Optional.
-
#name ⇒ String
Required.
-
#push_config ⇒ Google::Apis::PubsubV1::PushConfig
Configuration for a push delivery endpoint.
-
#retain_acked_messages ⇒ Boolean
(also: #retain_acked_messages?)
Optional.
-
#retry_policy ⇒ Google::Apis::PubsubV1::RetryPolicy
A policy that specifies how Pub/Sub retries message delivery.
-
#state ⇒ String
Output only.
-
#tags ⇒ Hash<String,String>
Optional.
-
#topic ⇒ String
Required.
-
#topic_message_retention_duration ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Subscription
constructor
A new instance of Subscription.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Subscription
Returns a new instance of Subscription.
2332 2333 2334 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2332 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ack_deadline_seconds ⇒ Fixnum
Optional. The approximate amount of time (on a best-effort basis) Pub/Sub
waits for the subscriber to acknowledge receipt before resending the message.
In the interval after the message is delivered and before it is acknowledged,
it is considered to be outstanding. During that time period, the message
will not be redelivered (on a best-effort basis). For pull subscriptions, this
value is used as the initial value for the ack deadline. To override this
value for a given message, call ModifyAckDeadline with the corresponding
ack_id if using non-streaming pull or send the ack_id in a
StreamingModifyAckDeadlineRequest if using streaming pull. The minimum custom
deadline you can specify is 10 seconds. The maximum custom deadline you can
specify is 600 seconds (10 minutes). If this parameter is 0, a default value
of 10 seconds is used. For push delivery, this value is also used to set the
request timeout for the call to the push endpoint. If the subscriber never
acknowledges the message, the Pub/Sub system will eventually redeliver the
message.
Corresponds to the JSON property ackDeadlineSeconds
2162 2163 2164 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2162 def ack_deadline_seconds @ack_deadline_seconds end |
#analytics_hub_subscription_info ⇒ Google::Apis::PubsubV1::AnalyticsHubSubscriptionInfo
Information about an associated Analytics Hub subscription.
Corresponds to the JSON property analyticsHubSubscriptionInfo
2168 2169 2170 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2168 def analytics_hub_subscription_info @analytics_hub_subscription_info end |
#bigquery_config ⇒ Google::Apis::PubsubV1::BigQueryConfig
Configuration for a BigQuery subscription.
Corresponds to the JSON property bigqueryConfig
2173 2174 2175 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2173 def bigquery_config @bigquery_config end |
#bigtable_config ⇒ Google::Apis::PubsubV1::BigtableConfig
Configuration for a Bigtable subscription. The Pub/Sub message will be written
to a Bigtable row as follows: - row key: subscription name and message ID
delimited by #. - columns: message bytes written to a single column family "
data" with an empty-string column qualifier. - cell timestamp: the message
publish timestamp.
Corresponds to the JSON property bigtableConfig
2182 2183 2184 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2182 def bigtable_config @bigtable_config end |
#cloud_storage_config ⇒ Google::Apis::PubsubV1::CloudStorageConfig
Configuration for a Cloud Storage subscription.
Corresponds to the JSON property cloudStorageConfig
2187 2188 2189 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2187 def cloud_storage_config @cloud_storage_config end |
#dead_letter_policy ⇒ Google::Apis::PubsubV1::DeadLetterPolicy
Dead lettering is done on a best effort basis. The same message might be dead
lettered multiple times. If validation on any of the fields fails at
subscription creation/updation, the create/update subscription request will
fail.
Corresponds to the JSON property deadLetterPolicy
2195 2196 2197 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2195 def dead_letter_policy @dead_letter_policy end |
#detached ⇒ Boolean Also known as: detached?
Optional. Indicates whether the subscription is detached from its topic.
Detached subscriptions don't receive messages from their topic and don't
retain any backlog. Pull and StreamingPull requests will return
FAILED_PRECONDITION. If the subscription is a push subscription, pushes to the
endpoint will not be made.
Corresponds to the JSON property detached
2204 2205 2206 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2204 def detached @detached end |
#enable_exactly_once_delivery ⇒ Boolean Also known as: enable_exactly_once_delivery?
Optional. If true, Pub/Sub provides the following guarantees for the delivery
of a message with a given value of message_id on this subscription: * The
message sent to a subscriber is guaranteed not to be resent before the message'
s acknowledgment deadline expires. * An acknowledged message will not be
resent to a subscriber. Note that subscribers may still receive multiple
copies of a message when enable_exactly_once_delivery is true if the message
was published multiple times by a publisher client. These copies are
considered distinct by Pub/Sub and have distinct message_id values.
Corresponds to the JSON property enableExactlyOnceDelivery
2217 2218 2219 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2217 def enable_exactly_once_delivery @enable_exactly_once_delivery end |
#enable_message_ordering ⇒ Boolean Also known as: enable_message_ordering?
Optional. If true, messages published with the same ordering_key in
PubsubMessage will be delivered to the subscribers in the order in which they
are received by the Pub/Sub system. Otherwise, they may be delivered in any
order.
Corresponds to the JSON property enableMessageOrdering
2226 2227 2228 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2226 def @enable_message_ordering end |
#expiration_policy ⇒ Google::Apis::PubsubV1::ExpirationPolicy
A policy that specifies the conditions for resource expiration (i.e.,
automatic resource deletion).
Corresponds to the JSON property expirationPolicy
2233 2234 2235 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2233 def expiration_policy @expiration_policy end |
#filter ⇒ String
Optional. An expression written in the Pub/Sub filter language. If non-empty, then only PubsubMessages
whose attributes field matches the filter are delivered on this subscription.
If empty, then no messages are filtered out.
Corresponds to the JSON property filter
2241 2242 2243 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2241 def filter @filter end |
#labels ⇒ Hash<String,String>
Optional. See Creating and managing labels.
Corresponds to the JSON property labels
2247 2248 2249 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2247 def labels @labels end |
#message_retention_duration ⇒ String
Optional. How long to retain unacknowledged messages in the subscription's
backlog, from the moment a message is published. If retain_acked_messages is
true, then this also configures the retention of acknowledged messages, and
thus configures how far back in time a Seek can be done. Defaults to 7 days.
Cannot be more than 31 days or less than 10 minutes.
Corresponds to the JSON property messageRetentionDuration
2256 2257 2258 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2256 def @message_retention_duration end |
#message_transforms ⇒ Array<Google::Apis::PubsubV1::MessageTransform>
Optional. Transforms to be applied to messages before they are delivered to
subscribers. Transforms are applied in the order specified.
Corresponds to the JSON property messageTransforms
2262 2263 2264 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2262 def @message_transforms end |
#name ⇒ String
Required. Identifier. The name of the subscription. It must have the format "
projects/project/subscriptions/subscription". subscription must start
with a letter, and contain only letters ([A-Za-z]), numbers ([0-9]),
dashes (-), underscores (_), periods (.), tildes (~), plus (+) or
percent signs (%). It must be between 3 and 255 characters in length, and it
must not start with "goog".
Corresponds to the JSON property name
2272 2273 2274 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2272 def name @name end |
#push_config ⇒ Google::Apis::PubsubV1::PushConfig
Configuration for a push delivery endpoint.
Corresponds to the JSON property pushConfig
2277 2278 2279 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2277 def push_config @push_config end |
#retain_acked_messages ⇒ Boolean Also known as: retain_acked_messages?
Optional. Indicates whether to retain acknowledged messages. If true, then
messages are not expunged from the subscription's backlog, even if they are
acknowledged, until they fall out of the message_retention_duration window.
This must be true if you would like to Seek to a timestamp in the past to replay
previously-acknowledged messages.
Corresponds to the JSON property retainAckedMessages
2287 2288 2289 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2287 def @retain_acked_messages end |
#retry_policy ⇒ Google::Apis::PubsubV1::RetryPolicy
A policy that specifies how Pub/Sub retries message delivery. Retry delay will
be exponential based on provided minimum and maximum backoffs. https://en.
wikipedia.org/wiki/Exponential_backoff. RetryPolicy will be triggered on NACKs
or acknowledgment deadline exceeded events for a given message. Retry Policy
is implemented on a best effort basis. At times, the delay between consecutive
deliveries may not match the configuration. That is, delay can be more or less
than configured backoff.
Corresponds to the JSON property retryPolicy
2299 2300 2301 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2299 def retry_policy @retry_policy end |
#state ⇒ String
Output only. An output-only field indicating whether or not the subscription
can receive messages.
Corresponds to the JSON property state
2305 2306 2307 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2305 def state @state end |
#tags ⇒ Hash<String,String>
Optional. Input only. Immutable. Tag keys/values directly bound to this
resource. For example: "123/environment": "production", "123/costCenter": "
marketing" See https://$universe.dns_names.final_documentation_domain/pubsub/
docs/tags for more information on using tags with Pub/Sub resources.
Corresponds to the JSON property tags
2313 2314 2315 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2313 def @tags end |
#topic ⇒ String
Required. The name of the topic from which this subscription is receiving
messages. Format is projects/project/topics/topic`. The value of this
field will bedeleted-topicif the topic has been deleted.
Corresponds to the JSON propertytopic`
2320 2321 2322 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2320 def topic @topic end |
#topic_message_retention_duration ⇒ String
Output only. Indicates the minimum duration for which a message is retained
after it is published to the subscription's topic. If this field is set,
messages published to the subscription's topic in the last
topic_message_retention_duration are always available to subscribers. See the
message_retention_duration field in Topic. This field is set only in
responses from the server; it is ignored if it is set in any requests.
Corresponds to the JSON property topicMessageRetentionDuration
2330 2331 2332 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2330 def @topic_message_retention_duration end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2337 2338 2339 2340 2341 2342 2343 2344 2345 2346 2347 2348 2349 2350 2351 2352 2353 2354 2355 2356 2357 2358 2359 2360 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2337 def update!(**args) @ack_deadline_seconds = args[:ack_deadline_seconds] if args.key?(:ack_deadline_seconds) @analytics_hub_subscription_info = args[:analytics_hub_subscription_info] if args.key?(:analytics_hub_subscription_info) @bigquery_config = args[:bigquery_config] if args.key?(:bigquery_config) @bigtable_config = args[:bigtable_config] if args.key?(:bigtable_config) @cloud_storage_config = args[:cloud_storage_config] if args.key?(:cloud_storage_config) @dead_letter_policy = args[:dead_letter_policy] if args.key?(:dead_letter_policy) @detached = args[:detached] if args.key?(:detached) @enable_exactly_once_delivery = args[:enable_exactly_once_delivery] if args.key?(:enable_exactly_once_delivery) @enable_message_ordering = args[:enable_message_ordering] if args.key?(:enable_message_ordering) @expiration_policy = args[:expiration_policy] if args.key?(:expiration_policy) @filter = args[:filter] if args.key?(:filter) @labels = args[:labels] if args.key?(:labels) @message_retention_duration = args[:message_retention_duration] if args.key?(:message_retention_duration) @message_transforms = args[:message_transforms] if args.key?(:message_transforms) @name = args[:name] if args.key?(:name) @push_config = args[:push_config] if args.key?(:push_config) @retain_acked_messages = args[:retain_acked_messages] if args.key?(:retain_acked_messages) @retry_policy = args[:retry_policy] if args.key?(:retry_policy) @state = args[:state] if args.key?(:state) @tags = args[:tags] if args.key?(:tags) @topic = args[:topic] if args.key?(:topic) @topic_message_retention_duration = args[:topic_message_retention_duration] if args.key?(:topic_message_retention_duration) end |