Class: Google::Apis::PubsubV1::UpdateSnapshotRequest
- Inherits:
-
Object
- Object
- Google::Apis::PubsubV1::UpdateSnapshotRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/pubsub_v1/classes.rb,
lib/google/apis/pubsub_v1/representations.rb,
lib/google/apis/pubsub_v1/representations.rb
Overview
Request for the UpdateSnapshot method.
Instance Attribute Summary collapse
-
#snapshot ⇒ Google::Apis::PubsubV1::Snapshot
A snapshot resource.
-
#update_mask ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UpdateSnapshotRequest
constructor
A new instance of UpdateSnapshotRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UpdateSnapshotRequest
Returns a new instance of UpdateSnapshotRequest.
2612 2613 2614 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2612 def initialize(**args) update!(**args) end |
Instance Attribute Details
#snapshot ⇒ Google::Apis::PubsubV1::Snapshot
A snapshot resource. Snapshots are used in Seek operations, which allow you to manage message
acknowledgments in bulk. That is, you can set the acknowledgment state of
messages in an existing subscription to the state captured by a snapshot.
Corresponds to the JSON property snapshot
2604 2605 2606 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2604 def snapshot @snapshot end |
#update_mask ⇒ String
Required. Indicates which fields in the provided snapshot to update. Must be
specified and non-empty.
Corresponds to the JSON property updateMask
2610 2611 2612 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2610 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2617 2618 2619 2620 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2617 def update!(**args) @snapshot = args[:snapshot] if args.key?(:snapshot) @update_mask = args[:update_mask] if args.key?(:update_mask) end |