Class: Google::Apis::PubsubV1::UpdateSnapshotRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/pubsub_v1/classes.rb,
lib/google/apis/pubsub_v1/representations.rb,
lib/google/apis/pubsub_v1/representations.rb

Overview

Request for the UpdateSnapshot method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpdateSnapshotRequest

Returns a new instance of UpdateSnapshotRequest.



2577
2578
2579
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2577

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#snapshotGoogle::Apis::PubsubV1::Snapshot

A snapshot resource. Snapshots are used in Seek operations, which allow you to manage message acknowledgments in bulk. That is, you can set the acknowledgment state of messages in an existing subscription to the state captured by a snapshot. Corresponds to the JSON property snapshot



2569
2570
2571
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2569

def snapshot
  @snapshot
end

#update_maskString

Required. Indicates which fields in the provided snapshot to update. Must be specified and non-empty. Corresponds to the JSON property updateMask

Returns:

  • (String)


2575
2576
2577
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2575

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2582
2583
2584
2585
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2582

def update!(**args)
  @snapshot = args[:snapshot] if args.key?(:snapshot)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end