Class: Google::Apis::PubsubV1::UpdateSubscriptionRequest
- Inherits:
-
Object
- Object
- Google::Apis::PubsubV1::UpdateSubscriptionRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/pubsub_v1/classes.rb,
lib/google/apis/pubsub_v1/representations.rb,
lib/google/apis/pubsub_v1/representations.rb
Overview
Request for the UpdateSubscription method.
Instance Attribute Summary collapse
-
#subscription ⇒ Google::Apis::PubsubV1::Subscription
A subscription resource.
-
#update_mask ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UpdateSubscriptionRequest
constructor
A new instance of UpdateSubscriptionRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UpdateSubscriptionRequest
Returns a new instance of UpdateSubscriptionRequest.
2530 2531 2532 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2530 def initialize(**args) update!(**args) end |
Instance Attribute Details
#subscription ⇒ Google::Apis::PubsubV1::Subscription
A subscription resource. If none of push_config, bigquery_config, or
cloud_storage_config is set, then the subscriber will pull and ack messages
using API methods. At most one of these fields may be set.
Corresponds to the JSON property subscription
2522 2523 2524 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2522 def subscription @subscription end |
#update_mask ⇒ String
Required. Indicates which fields in the provided subscription to update. Must
be specified and non-empty.
Corresponds to the JSON property updateMask
2528 2529 2530 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2528 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2535 2536 2537 2538 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2535 def update!(**args) @subscription = args[:subscription] if args.key?(:subscription) @update_mask = args[:update_mask] if args.key?(:update_mask) end |