Class: Google::Apis::PubsubV1::UpdateTopicRequest
- Inherits:
-
Object
- Object
- Google::Apis::PubsubV1::UpdateTopicRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/pubsub_v1/classes.rb,
lib/google/apis/pubsub_v1/representations.rb,
lib/google/apis/pubsub_v1/representations.rb
Overview
Request for the UpdateTopic method.
Instance Attribute Summary collapse
-
#topic ⇒ Google::Apis::PubsubV1::Topic
A topic resource.
-
#update_mask ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UpdateTopicRequest
constructor
A new instance of UpdateTopicRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UpdateTopicRequest
Returns a new instance of UpdateTopicRequest.
2635 2636 2637 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2635 def initialize(**args) update!(**args) end |
Instance Attribute Details
#topic ⇒ Google::Apis::PubsubV1::Topic
A topic resource.
Corresponds to the JSON property topic
2624 2625 2626 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2624 def topic @topic end |
#update_mask ⇒ String
Required. Indicates which fields in the provided topic to update. Must be
specified and non-empty. Note that if update_mask contains "
message_storage_policy" but the message_storage_policy is not set in the
topic provided above, then the updated value is determined by the policy
configured at the project or organization level.
Corresponds to the JSON property updateMask
2633 2634 2635 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2633 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2640 2641 2642 2643 |
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2640 def update!(**args) @topic = args[:topic] if args.key?(:topic) @update_mask = args[:update_mask] if args.key?(:update_mask) end |