Class: Google::Apis::PubsubV1::UpdateTopicRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/pubsub_v1/classes.rb,
lib/google/apis/pubsub_v1/representations.rb,
lib/google/apis/pubsub_v1/representations.rb

Overview

Request for the UpdateTopic method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpdateTopicRequest

Returns a new instance of UpdateTopicRequest.



2493
2494
2495
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2493

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#topicGoogle::Apis::PubsubV1::Topic

A topic resource. Corresponds to the JSON property topic



2482
2483
2484
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2482

def topic
  @topic
end

#update_maskString

Required. Indicates which fields in the provided topic to update. Must be specified and non-empty. Note that if update_mask contains " message_storage_policy" but the message_storage_policy is not set in the topic provided above, then the updated value is determined by the policy configured at the project or organization level. Corresponds to the JSON property updateMask

Returns:

  • (String)


2491
2492
2493
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2491

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2498
2499
2500
2501
# File 'lib/google/apis/pubsub_v1/classes.rb', line 2498

def update!(**args)
  @topic = args[:topic] if args.key?(:topic)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end